@@ -28,7 +28,7 @@ cv.tree <- function(object, rand, FUN = prune.tree, K = 10, ...)
     extras <- match.call(expand.dots = FALSE)$...
     FUN <- deparse(substitute(FUN))
     init <- do.call(FUN, c(list(object), extras))
-    if(missing(rand)) rand <- sample(K, length(m[[1]]), replace = TRUE)
+    if(missing(rand)) rand <- sample(K, length(m[[1L]]), replace = TRUE)
     cvdev <- 0
     for(i in unique(rand)) {
         tlearn <- tree(model = m[rand != i,  , drop = FALSE])
@@ -44,7 +44,7 @@ cv.tree <- function(object, rand, FUN = prune.tree, K = 10, ...)
 data.tree <- function(tree)
 {
     oc <- tree$call
-    while(oc[[1]] != "tree") oc <- eval(oc[[2]])$call
+    while(oc[[1L]] != "tree") oc <- eval(oc[[2L]])$call
     if(is.null(oc$data)) NULL
     else {
         warning("retrieving data from ", deparse(oc$data))
@@ -55,17 +55,17 @@ data.tree <- function(tree)
 descendants <- function(nodes, include = TRUE)
 {
     n <- length(nodes)
-    if(n == 1) return(matrix(TRUE, 1, 1))
-    ind <- 1:n
+    if(n == 1L) return(matrix(TRUE, 1L, 1L))
+    ind <- 1L:n
     desc <- matrix(FALSE, n, n)
     if(include) diag(desc) <- TRUE
     parents <- match((nodes %/% 2), nodes)
     lev <- floor(log(nodes, base = 2))
-    desc[1, 2:n] <- TRUE
+    desc[1L, 2L:n] <- TRUE
     for(i in max(lev):2) {
         desc[cbind(ind[parents[lev == i]], ind[lev == i])] <- TRUE
         parents[lev == i] <- parents[parents[lev == i]]
-        lev[lev == i] <- i - 1
+        lev[lev == i] <- i - 1L
     }
     return(desc)
 }
@@ -88,10 +88,10 @@ labels.tree <- function(object, pretty = TRUE, collapse = TRUE, ...)
     if(!is.null(pretty)) {
         if(pretty) xlevels <- lapply(xlevels, abbreviate, minlength=pretty)
         for(i in grep("^:", splits[, 1]))
-            for(j in 1:2) {
+            for(j in 1L:2L) {
                 sh <- splits[i, j]
                 nc <- nchar(sh)
-                sh <- substring(sh, 2:nc, 2:nc)
+                sh <- substring(sh, 2L:nc, 2L:nc)
                 xl <- xlevels[[var[i]]][match(sh, letters)]
                 splits[i, j] <- paste(": ",
                                       paste(as.vector(xl), collapse=","),
@@ -103,9 +103,9 @@ labels.tree <- function(object, pretty = TRUE, collapse = TRUE, ...)
     node <- as.numeric(row.names(frame))
     parent <- match((node %/% 2), node)
     odd <- as.logical(node %% 2)
-    node[odd] <- paste(var[parent[odd]], splits[parent[odd], 2], sep = "")
-    node[!odd] <- paste(var[parent[!odd]], splits[parent[!odd], 1], sep = "")
-    node[1] <- "root"
+    node[odd] <- paste(var[parent[odd]], splits[parent[odd], 2L], sep = "")
+    node[!odd] <- paste(var[parent[!odd]], splits[parent[!odd], 1L], sep = "")
+    node[1L] <- "root"
     node
 }
 
@@ -135,7 +135,7 @@ model.frame.tree <- function(formula, ...)
 {
     if(!is.null(m <- formula$model)) return(m)
     oc <- formula$call
-    if(substring(deparse(oc[[1]]), 1, 7) == "predict") {
+    if(substring(deparse(oc[[1L]]), 1L, 7L) == "predict") {
         m <- eval(oc$newdata)
         if(is.null(attr(m, "terms"))) {
             object <- eval(oc$object)
@@ -143,7 +143,7 @@ model.frame.tree <- function(formula, ...)
         }
         return(m)
     }
-    while(deparse(oc[[1]]) != "tree")  oc <- eval(oc[[2]])$call
+    while(deparse(oc[[1L]]) != "tree")  oc <- eval(oc[[2L]])$call
     oc$subset <- names(formula$where)
     oc$method <- "model.frame"
     eval(oc)
@@ -151,45 +151,45 @@ model.frame.tree <- function(formula, ...)
 
 node.match <- function(nodes, nodelist, leaves, print.it = TRUE)
 {
-    node.index <- match(nodes, nodelist, nomatch = 0)
-    bad <- nodes[node.index == 0]
-    if(length(bad) > 0 & print.it)
+    node.index <- match(nodes, nodelist, nomatch = 0L)
+    bad <- nodes[node.index == 0L]
+    if(length(bad) > 0L & print.it)
         warning("supplied nodes ", paste(bad, collapse = ","),
                 " are not in this tree")
-    good <- nodes[node.index > 0]
+    good <- nodes[node.index > 0L]
     if(!missing(leaves) && any(leaves <- leaves[node.index])) {
         warning("supplied nodes ",
                 paste(good[leaves], collapse = ","), " are leaves")
-        node.index[node.index > 0][!leaves]
+        node.index[node.index > 0L][!leaves]
     }
-    else node.index[node.index > 0]
+    else node.index[node.index > 0L]
 }
 
 partition.tree <- function(tree, label = "yval", add = FALSE, ordvars, ...)
 {
-    ptXlines <- function(x, v, xrange, xcoord = NULL, ycoord = NULL, tvar, i = 1)
+    ptXlines <- function(x, v, xrange, xcoord = NULL, ycoord = NULL, tvar, i = 1L)
     {
         if(v[i] == "<leaf>") {
-            y1 <- (xrange[1] + xrange[3])/2
-            y2 <- (xrange[2] + xrange[4])/2
+            y1 <- (xrange[1L] + xrange[3L])/2
+            y2 <- (xrange[2L] + xrange[4L])/2
             return(list(xcoord = xcoord, ycoord = c(ycoord, y1, y2), i = i))
         }
-        if(v[i] == tvar[1]) {
-            xcoord <- c(xcoord, x[i], xrange[2], x[i], xrange[4])
+        if(v[i] == tvar[1L]) {
+            xcoord <- c(xcoord, x[i], xrange[2L], x[i], xrange[4L])
             xr <- xrange
-            xr[3] <- x[i]
-            ll2 <- Recall(x, v, xr, xcoord, ycoord, tvar, i + 1)
+            xr[3L] <- x[i]
+            ll2 <- Recall(x, v, xr, xcoord, ycoord, tvar, i + 1L)
             xr <- xrange
-            xr[1] <- x[i]
-            return(Recall(x, v, xr, ll2$xcoord, ll2$ycoord, tvar, ll2$i + 1))
-        } else if(v[i] == tvar[2]) {
-            xcoord <- c(xcoord, xrange[1], x[i], xrange[3], x[i])
+            xr[1L] <- x[i]
+            return(Recall(x, v, xr, ll2$xcoord, ll2$ycoord, tvar, ll2$i + 1L))
+        } else if(v[i] == tvar[2L]) {
+            xcoord <- c(xcoord, xrange[1L], x[i], xrange[3L], x[i])
             xr <- xrange
-            xr[4] <- x[i]
-            ll2 <- Recall(x, v, xr, xcoord, ycoord, tvar, i + 1)
+            xr[4L] <- x[i]
+            ll2 <- Recall(x, v, xr, xcoord, ycoord, tvar, i + 1L)
             xr <- xrange
-            xr[2] <- x[i]
-            return(Recall(x, v, xr, ll2$xcoord, ll2$ycoord, tvar, ll2$i + 1))
+            xr[2L] <- x[i]
+            return(Recall(x, v, xr, ll2$xcoord, ll2$ycoord, tvar, ll2$i + 1L))
         }
         else stop("wrong variable numbers in tree.")
     }
@@ -198,19 +198,20 @@ partition.tree <- function(tree, label = "yval", add = FALSE, ordvars, ...)
     frame <- tree$frame
     leaves <- frame$var == "<leaf>"
     var <- unique(as.character(frame$var[!leaves]))
-    if(length(var) > 2 || length(var) < 1)
+    if(length(var) > 2L || length(var) < 1L)
         stop("tree can only have one or two predictors")
     nlevels <- sapply(attr(tree, "xlevels"), length)
-    if(any(nlevels[var] > 0))
+    if(any(nlevels[var] > 0L))
         stop("tree can only have continuous predictors")
     x <- rep(NA, length(leaves))
-    x[!leaves] <- as.double(substring(frame$splits[!leaves, "cutleft"], 2, 100))
+    x[!leaves] <- as.double(substring(frame$splits[!leaves, "cutleft"],
+                                      2L, 100L))
     m <- model.frame(tree)
-    if(length(var) == 1) {
+    if(length(var) == 1L) {
         ## one x variable
         x <- sort(c(range(m[[var]]), x[!leaves]))
         if(is.null(attr(tree, "ylevels"))) y <- frame$yval[leaves]
-        else y <- frame$yprob[, 1]
+        else y <- frame$yprob[, 1L]
         y <- c(y, y[length(y)])
         if(add) lines(x, y, type = "s", ...)
         else {
@@ -230,24 +231,24 @@ partition.tree <- function(tree, label = "yval", add = FALSE, ordvars, ...)
             var <- ordvars[sort(ind)]
         }
         lab <- frame$yval[leaves]
-        if(is.null(frame$yprob)) lab <- format(signif(lab, 3))
-        else if(match(label, attr(tree, "ylevels"), nomatch = 0))
-            lab <- format(signif(frame$yprob[leaves, label], 3))
-        rx <- range(m[[var[1]]])
+        if(is.null(frame$yprob)) lab <- format(signif(lab, 3L))
+        else if(match(label, attr(tree, "ylevels"), nomatch = 0L))
+            lab <- format(signif(frame$yprob[leaves, label], 3L))
+        rx <- range(m[[var[1L]]])
         rx <- rx + c(-0.025, 0.025) * diff(rx)
-        rz <- range(m[[var[2]]])
+        rz <- range(m[[var[2L]]])
         rz <- rz + c(-0.025, 0.025) * diff(rz)
         xrange <- c(rx, rz)[c(1, 3, 2, 4)]
         xcoord <- NULL                  # x1lo, x2lo, x1hi, x2hi
         ycoord <- NULL                  # y1, y2
         xy <- ptXlines(x, frame$var, xrange, xcoord, ycoord, var)
-        xx <- matrix(xy$xcoord, nrow = 4)
-        yy <- matrix(xy$ycoord, nrow = 2)
+        xx <- matrix(xy$xcoord, nrow = 4L)
+        yy <- matrix(xy$ycoord, nrow = 2L)
         if(!add)
-            plot(rx, rz, xlab = var[1], ylab = var[2], type = "n",
+            plot(rx, rz, xlab = var[1L], ylab = var[2L], type = "n",
                  xaxs = "i", yaxs = "i", ...)
-        segments(xx[1,  ], xx[2,  ], xx[3,  ], xx[4,  ])
-        text(yy[1,  ], yy[2,  ], as.character(lab), ...)
+        segments(xx[1L,  ], xx[2L,  ], xx[3L,  ], xx[4L,  ])
+        text(yy[1L,  ], yy[2L,  ], as.character(lab), ...)
     }
 }
 
@@ -259,7 +260,7 @@ plot.tree <- function (x, y = NULL,
     type <- match.arg(type)
     uniform <- type == "uniform"
     dev <- dev.cur()
-    if (dev == 1) dev <- 2 # as device will be opened.
+    if (dev == 1L) dev <- 2L # as device will be opened.
     assign(paste(".Tree.unif", dev, sep = "."), uniform, envir=.GlobalEnv)
     invisible(treepl(treeco(x), node=as.numeric(row.names(x$frame)), ...))
 }
@@ -277,8 +278,8 @@ print.tree <-
     depth <- tree.depth(node)
     indent <- paste(rep(" ", spaces * 32), collapse = "")
                                      #32 is the maximal depth
-    if(length(node) > 1) {
-        indent <- substring(indent, 1, spaces * seq(depth))
+    if(length(node) > 1L) {
+        indent <- substring(indent, 1L, spaces * seq(depth))
         indent <- paste(c("", indent[depth]), format(node), ")", sep = "")
     } else
     indent <- paste(format(node), ")", sep = "")
@@ -292,7 +293,7 @@ print.tree <-
     term <- rep(" ", length(depth))
     term[frame$var == "<leaf>"] <- "*"
     z <- labels.tree(x, pretty = pretty)
-    z <- paste(indent, z, round(frame$n,2),
+    z <- paste(indent, z, round(frame$n, 2L),
                format(signif(frame$dev, digits = digits)),
                yval, term)
     cat(z, sep = "\n")
@@ -331,7 +332,7 @@ snip.tree <-
         frame$var[i] <- "<leaf>"
         frame$splits[i,  ] <- ""
         ii <- frame$which[i,  , drop = FALSE]
-        keep <- !apply(ii, 2, any)
+        keep <- !apply(ii, 2L, any)
         frame <- frame[keep,  , drop = FALSE]
         frame$which <- frame$which[, keep, drop = FALSE]
         where <- match(node[where], node[keep])
@@ -347,13 +348,13 @@ snip.tree <-
     call <- match.call()
     node <- as.numeric(row.names(tree$frame))
     if(missing(nodes)) {
-        iprev <- i <- 0
+        iprev <- i <- 0L
         nodes <- NULL
         totdev <- deviance(tree)
         xy <- treeco(tree)
         tree$frame$which <- descendants(node, include = FALSE)
         labs <- c("node number: ", "  tree deviance = ", "  subtree deviance = ")
-        while(length(i <- identify(xy$x, xy$y, n=1, plot=FALSE)) > 0) {
+        while(length(i <- identify(xy$x, xy$y, n=1, plot=FALSE)) > 0L) {
             if(tree$frame$var[i] == "<leaf>") {
                 cat("Terminal node -- try again\n")
                 next
@@ -377,7 +378,7 @@ snip.tree <-
         if(xy.save) assign(".xy", xy, envir=.GlobalEnv)
     } else {
         i <- node.match(nodes, node, tree$frame$var == "<leaf>")
-        if(length(i) == 0) return(tree)
+        if(length(i) == 0L) return(tree)
         nodes <- node[i]
         which <- descendants(node, include = TRUE)
         nodes <- nodes[colSums(which[i,  ] %*% which[, i]) == 1]
@@ -388,7 +389,7 @@ snip.tree <-
     tree$frame$which <- NULL
     call$nodes <- nodes
     tree$call <- call
-    if(dim(tree$frame)[1] == 1) class(tree) <- "singlenode"
+    if(dim(tree$frame)[1L] == 1L) class(tree) <- "singlenode"
     tree
 }
 
@@ -403,9 +404,9 @@ summary.tree <- function(object, ...)
     used <- unique(frame$var[!leaves])
     if(length(used) < length(variables)) obj$used <- used
     obj$size <- sum(leaves)
-    obj$df <- frame$n[1] - obj$size
+    obj$df <- frame$n[1L] - obj$size
     obj$dev <- deviance.tree(object)
-    if(!is.reg) obj$misclass <- c(misclass.tree(object), frame$n[1])
+    if(!is.reg) obj$misclass <- c(misclass.tree(object), frame$n[1L])
     else obj$residuals <- residuals(object)
     class(obj) <- "summary.tree"
     obj
@@ -430,8 +431,8 @@ print.summary.tree <-
               format(signif(x$df, digits)), "\n"))
     if(!is.null(x$misclass))
         cat("Misclassification error rate:",
-            format(signif(x$misclass[1]/x$misclass[2], digits)),
-            "=", x$misclass[1], "/", x$ misclass[2], "\n")
+            format(signif(x$misclass[1L]/x$misclass[2L], digits)),
+            "=", x$misclass[1L], "/", x$ misclass[2L], "\n")
     else {
         cat("Distribution of residuals:\n")
         print(summary(x$residuals, digits = digits, ...))
@@ -453,7 +454,7 @@ text.tree <-
     if(!is.null(ylevels <- attr(x, "ylevels"))) column <- c(column, ylevels)
     if(!is.null(label) && is.na(match(label, column)))
         stop("label must be a column label of the frame component of the tree")
-    charht <- par("cxy")[2]
+    charht <- par("cxy")[2L]
     if(!is.null(srt <- list(...)$srt) && srt == 90) {
         if(missing(adj)) adj <- 0
         ladj <- 1 - adj
@@ -473,9 +474,9 @@ text.tree <-
         else if(!is.null(ylevels) && !is.na(lev <- match(label, ylevels)))
             stat <- format(signif(frame$yprob[leaves, lev], digits = digits))
         else stat <- format(signif(frame[leaves, label], digits = digits))
-        if(!is.null(dim(stat)) && dim(stat)[2] > 1) {
-            if(length(dimnames(stat)[[2]]))
-                stat[1,  ] <- paste(sep = ":", dimnames(stat)[[2]], stat[1,  ])
+        if(!is.null(dim(stat)) && dim(stat)[2L] > 1) {
+            if(length(dimnames(stat)[[2L]]))
+                stat[1,  ] <- paste(sep = ":", dimnames(stat)[[2L]], stat[1,  ])
             stat <- do.call("paste",
                             c(list(sep = "\n"), split(stat, col(stat)))
                             )
@@ -493,7 +494,7 @@ tile.tree <- function(tree, var, screen.arg = ascr + 1, axes = TRUE)
     where <- tree$where
     varname <- substitute(var)
     v <- match(deparse(varname), as.character(attr(tree$terms, "variables")),
-               nomatch = 0)
+               nomatch = 0L)
     if(v) var <- model.frame(tree)[, v]
     else {
         if(!is.null(data <- data.tree(tree))) {
@@ -507,17 +508,17 @@ tile.tree <- function(tree, var, screen.arg = ascr + 1, axes = TRUE)
     if(any(is.na(var))) var <- na.tree.replace(list(var = var))$var
     if(!(levx <- length(levels(var)))) {
         var <- cut(var, quantile(var) - c(1, 0, 0, 0, 0))
-        levx <- 4
+        levx <- 4L
         names(var) <- names(where)
     }
     leaves <- tree$frame$var == "<leaf>"
     nl <- sum(leaves)
     x <- seq(nl)
     indices <- unlist(split(names(where), where))
-    counts <- c(table(var[indices], rep(1:nl, tree$frame$n[leaves])))
+    counts <- c(table(var[indices], rep(1L:nl, tree$frame$n[leaves])))
     xm <- max(x)
-    y <- seq(0, 1, length = levx + 1)[-1]
-    dy <- y[2] - y[1]
+    y <- seq(0, 1, length = levx + 1L)[-1L]
+    dy <- y[2L] - y[1L]
     y <- rep(y, nl)[as.logical(counts)]
     x <- rep(x, rep(levx, nl))[as.logical(counts)]
     dx <- counts[as.logical(counts)]/(max(counts) * 2)
@@ -568,14 +569,14 @@ tree.matrix <- function(frame)
     else predictors <- as.character(attr(terms, "term.labels"))
     frame <- frame[predictors]
     term.levels <- lapply(frame, levels)
-    factors <- sapply(term.levels, function(x) length(x) > 0)
+    factors <- sapply(term.levels, function(x) length(x) > 0L)
     if(any(factors)) {
         for(preds in predictors[factors])
             frame[[preds]] <- as.vector(unclass(frame[[preds]]))
         x <- as.matrix(frame)
         column.levels <- vector("list", ncol(x))
-        names(column.levels) <- dimnames(x)[[2]]
-        TT <- term.levels[factors > 0]
+        names(column.levels) <- dimnames(x)[[2L]]
+        TT <- term.levels[factors > 0L]
         column.levels[names(TT)] <- TT
         attr(x, "column.levels") <- column.levels
     }
@@ -587,7 +588,7 @@ tree.matrix <- function(frame)
 tree.screens <- function(figs, screen.arg = 0, ...)
 {
     if(missing(figs))
-        figs <- matrix(c(0, 0, 1, 1, 0.25, 0.05, 1, 0.25), 2, 4)
+        figs <- matrix(c(0, 0, 1, 1, 0.25, 0.05, 1, 0.25), 2L, 4L)
     which <- split.screen(figs, screen.arg)
     par(mar = rep(0, 4), cex = 1, ...)
     which
@@ -607,16 +608,16 @@ treeco <-
         y <- dev <- frame$dev
         depth <- split(seq(node), depth)
         parent <- match(node %/% 2, node)
-        sibling <- match(ifelse(node %% 2, node - 1, node + 1), node)
-        for(i in depth[-1])
+        sibling <- match(ifelse(node %% 2, node - 1L, node + 1L), node)
+        for(i in depth[-1L])
             y[i] <- y[parent[i]] - dev[parent[i]] + dev[i] + dev[sibling[i]]
     }
     depth <-  -x
     leaves <- frame$var == "<leaf>"
     x[leaves] <- seq(sum(leaves))
     depth <- split(seq(node)[!leaves], depth[!leaves])
-    left.child <- match(node * 2, node)
-    right.child <- match(node * 2 + 1, node)
+    left.child <- match(node * 2L, node)
+    right.child <- match(node * 2 + 1L, node)
     for(i in rev(depth)) x[i] <- 0.5 * (x[left.child[i]] + x[right.child[i]])
     list(x = x, y = y)
 }
@@ -625,7 +626,7 @@ treepl <- function(xy, node, erase = FALSE, ...)
 {
     x <- xy$x; y <- xy$y
     parent <- match((node %/% 2), node)
-    sibling <- match(ifelse(node %% 2, node - 1, node + 1), node)
+    sibling <- match(ifelse(node %% 2, node - 1L, node + 1L), node)
     xx <- rbind(x, x, x[sibling], x[sibling], NA)
     yy <- rbind(y, y[parent], y[parent], y[sibling], NA)
     if(any(erase)) {
@@ -633,7 +634,7 @@ treepl <- function(xy, node, erase = FALSE, ...)
         return(x = x[!erase], y = y[!erase])
     }
     plot(range(x), range(y), type = "n", axes = FALSE, xlab = "", ylab = "")
-    text(x[1], y[1], "|", ...)
+    text(x[1L], y[1L], "|", ...)
     lines(c(xx[, -1]), c(yy[, -1]), ...)
     list(x = x, y = y)
 }
